@@ -18,7 +18,7 @@ if PY2:
 else:
     from xmlrpc.client import ServerProxy
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 __author__ = "Steven Loria"
 __license__ = "MIT"
 
@@ -41,11 +41,12 @@ def lazy_property(fn):
 
 def get_display_width():
     """Get the maximum display width to output."""
-    if PY2:  # Python 2 does not have get_terminal_size, so just get it fron
-            # the environment variable and fallback to 80
-        return int(os.environ.get('COLUMNS', 80))
-    else:  # On Python 3, we can use the entire width of the terminal
+    fallback = int(os.environ.get('COLUMNS', 80))
+    try:  # On Python 3.3, we can use the entire width of the terminal
         return os.get_terminal_size().columns
+    except (AttributeError, OSError):
+        pass
+    return fallback
 
 
 def bargraph(data):
@@ -57,7 +58,10 @@ def bargraph(data):
     max_bar_width = get_display_width() - (max_length + 3 + max_val_length + 3)
     template = "{key:{key_width}} [ {value:{val_width},d} ] {bar}"
     for key, value in data.items():
-        bar = int(math.ceil(max_bar_width * value / max_val)) * TICK
+        try:
+            bar = int(math.ceil(max_bar_width * value / max_val)) * TICK
+        except ZeroDivisionError:
+            bar = ''
         line = template.format(key=key[:max_length], value=value,
             bar=bar, key_width=max_length, val_width=max_val_length)
         lines.append(line)
